Welcome to Django SHOP’s documentation! — Django Shop v0.0.0 documentation

### Navigation

- index
- next |
- Django Shop v0.0.0 documentation »

# Welcome to Django SHOP’s documentation!

## User Manual

The “instructions” :)

- 1. Getting started
- 2. Contributing

## How to

Various short articles on how to do specific things

- 1. How to create a product
  - 1.1. Create a model
  - 1.2. Create a template
  - 1.3. Using your newly created Product
  - 1.4. Product variations
- 2. How to create a Cart modifier
- 3. How to create a Payment backend
  - 3.1. Shop interface
  - 3.2. Backend interface
- 4. How to create a shipping backend
  - 4.1. Shop interface
  - 4.2. Backend interface

## Reference

Reference sheets and lists regarding django SHOP

- 1. Plugins
- 2. General Settings
- 3. Backend specific Settings

### Navigation

- index
- next |
- Django Shop v0.0.0 documentation »